.. Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.contribute:

===================================
 Getting Involved and Contributing
===================================

We will happily accept external contributions, but substantial contributions
require a signed Contributor or `Copyright License Agreement <cla_>`_ (CLA).
Our CLA, based on `Project Harmony`_, leaves copyright with you (the
contributor), but allows us to relicense the code, with a restriction based on
the license the contribution was made under.

Contact our `Technology Transfer Officer <tto_>`_ to get a copy of the CLA_ for
this project.  If you work for a company and your contributions are tied to
your job, ensure you have the legal right to sign this CLA, or refer to the
responsible person during your e-mail exchange with our TTO_.


.. include:: links.rst
